import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post } from '../../services/api';

/**
 * 获取聊天消息
 * @param {string} conversationId - 会话ID
 */
export const fetchMessages = createAsyncThunk('chat/fetchMessages', async (conversationId, { rejectWithValue }) => {
    try {
        const response = await get(`/chat-history/conversation_detail`, {
            params: { conversation_id: conversationId },
        });

        // 处理返回格式
        if (response && response.code === 200) {
            return response.data.messages || [];
        }

        return [];
    } catch (error) {
        return rejectWithValue(error.response?.data?.message || 'Failed to fetch messages');
    }
});

/**
 * 发送聊天消息
 * @param {Object} params - 消息参数
 * @param {string} params.chatId - 聊天ID
 * @param {string} params.content - 消息内容
 */
export const sendMessage = createAsyncThunk('chat/sendMessage', async ({ chatId, content }, { rejectWithValue }) => {
    try {
        const response = await post(`/chat-history/${chatId}/messages/`, {
            content,
            type: 'text',
        });

        // 处理返回格式
        if (response && response.code === 200) {
            return {
                ...response.data,
                role: response.data.role || 'user', // 确保有角色字段
            };
        }

        return response.data || {};
    } catch (error) {
        return rejectWithValue(error.response?.data?.message || 'Failed to send message');
    }
});
