import { createSlice } from '@reduxjs/toolkit';
import { refreshGmailWatch, setupGmailChat, checkGmailAuth } from './gmailChat.thunks';

const initialState = {
    status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
    error: null,
    data: {
        historyId: null,
        expiration: null,
        wasExpired: null,
        gmailEmail: null,
    },
    setup: {
        status: 'idle',
        error: null,
        knowledgeBaseId: null,
        conversationId: null,
        message: null,
        noEmailsWarning: null,
        troubleshooting: null,
    },
    auth: {
        status: 'idle',
        error: null,
        isAuthenticated: false,
        needsSetup: false,
        watchExpired: false,
        lastHistoryId: null,
        watchExpiration: null,
    },
};

const gmailChatSlice = createSlice({
    name: 'gmailChat',
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            .addCase(refreshGmailWatch.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(refreshGmailWatch.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.data = {
                    historyId: action.payload.data.history_id,
                    expiration: action.payload.data.expiration,
                    wasExpired: action.payload.data.was_expired,
                    gmailEmail: action.payload.data.gmail_email,
                };
                state.error = null;
            })
            .addCase(refreshGmailWatch.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(setupGmailChat.pending, (state) => {
                state.setup.status = 'loading';
                state.setup.noEmailsWarning = null;
                state.setup.troubleshooting = null;
            })
            .addCase(setupGmailChat.fulfilled, (state, action) => {
                state.setup.status = 'succeeded';

                if (action.payload.message && action.payload.message.includes('没有找到')) {
                    state.setup.noEmailsWarning = action.payload.message;
                    state.setup.troubleshooting = action.payload.troubleshooting || null;
                } else {
                    state.setup.noEmailsWarning = null;
                    state.setup.troubleshooting = null;
                }

                state.setup.knowledgeBaseId =
                    action.payload.knowledge_base_id || action.payload.data?.knowledge_base_id;
                state.setup.conversationId = action.payload.conversation_id || action.payload.data?.conversation_id;
                state.setup.message = action.payload.message;
                state.setup.error = null;
            })
            .addCase(setupGmailChat.rejected, (state, action) => {
                state.setup.status = 'failed';
                state.setup.error = action.error.message;
            })
            .addCase(checkGmailAuth.pending, (state) => {
                state.auth.status = 'loading';
            })
            .addCase(checkGmailAuth.fulfilled, (state, action) => {
                state.auth.status = 'succeeded';
                state.auth.isAuthenticated = action.payload.data.authenticated;
                state.auth.needsSetup = action.payload.data.needs_setup;
                state.auth.watchExpired = action.payload.data.watch_expired;
                state.auth.lastHistoryId = action.payload.data.last_history_id;
                state.auth.watchExpiration = action.payload.data.watch_expiration;
                state.auth.error = null;
            })
            .addCase(checkGmailAuth.rejected, (state, action) => {
                state.auth.status = 'failed';
                state.auth.error = action.error.message;
            });
    },
});

export default gmailChatSlice.reducer;
