import { createAsyncThunk } from '@reduxjs/toolkit';
import axios from 'axios';
import { post } from '../../services/api';

export const refreshGmailWatch = createAsyncThunk('gmailChat/refreshGmailWatch', async (_, { rejectWithValue }) => {
    try {
        const requestData = {
            use_proxy: true,
            proxy_url: 'http://127.0.0.1:7890',
        };

        const response = await post('/gmail/refresh-watch/', requestData);
        return response;
    } catch (error) {
        const errorMessage = error.response?.data?.message || 'Failed to refresh Gmail watch';
        return rejectWithValue(errorMessage);
    }
});

export const setupGmailChat = createAsyncThunk('gmailChat/setupGmailChat', async (payload, { rejectWithValue }) => {
    try {
        let requestData;

        // 处理两种不同的调用情况：只传入邮箱字符串 或 传入包含auth_code的对象
        if (typeof payload === 'string') {
            // 第一次调用，只传入达人邮箱
            requestData = {
                client_secret_json: {
                    installed: {
                        client_id: '266164728215-v84lngbp3vgr4ulql01sqkg5vaigf4a5.apps.googleusercontent.com',
                        project_id: 'knowledge-454905',
                        auth_uri: 'https://accounts.google.com/o/oauth2/auth',
                        token_uri: 'https://oauth2.googleapis.com/token',
                        auth_provider_x509_cert_url: 'https://www.googleapis.com/oauth2/v1/certs',
                        client_secret: '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',
                        redirect_uris: ['http://localhost'],
                    },
                },
                talent_gmail: payload,
				auth_code: "",
            };
        } else {
            // 第二次调用，包含授权码
            requestData = {
                client_secret_json: {
                    installed: {
                        client_id: '266164728215-v84lngbp3vgr4ulql01sqkg5vaigf4a5.apps.googleusercontent.com',
                        project_id: 'knowledge-454905',
                        auth_uri: 'https://accounts.google.com/o/oauth2/auth',
                        token_uri: 'https://oauth2.googleapis.com/token',
                        auth_provider_x509_cert_url: 'https://www.googleapis.com/oauth2/v1/certs',
                        client_secret: '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',
                        redirect_uris: ['http://localhost'],
                    },
                },
                talent_gmail: payload.talent_gmail,
                auth_code: payload.auth_code,
            };
        }

        const response = await post('/gmail/setup/', requestData);
        return response;
    } catch (error) {
        return rejectWithValue(error.response?.data?.message || error.message || 'Failed to setup Gmail chat');
    }
});

export const checkGmailAuth = createAsyncThunk('gmailChat/checkAuth', async (_, { rejectWithValue }) => {
    try {
        const response = await axios.get('/gmail/check-auth/');
        return response.data;
    } catch (error) {
        const errorMessage = error.response?.data?.message || 'Failed to check Gmail authentication';
        return rejectWithValue(errorMessage);
    }
});
