import { createSlice } from '@reduxjs/toolkit';
import { setUserGoal, getConversationSummary, getRecommendedReply } from './talentChat.thunks';

// 初始状态
const initialState = {
    userGoal: {
        data: null,
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null
    },
    conversationSummary: {
        data: null,
        status: 'idle',
        error: null
    },
    recommendedReply: {
        data: null,
        status: 'idle',
        error: null
    }
};

// 创建 slice
const talentChatSlice = createSlice({
    name: 'talentChat',
    initialState,
    reducers: {
        resetTalentChat: (state) => {
            state.userGoal = { data: null, status: 'idle', error: null };
            state.conversationSummary = { data: null, status: 'idle', error: null };
            state.recommendedReply = { data: null, status: 'idle', error: null };
        }
    },
    extraReducers: (builder) => {
        // 设置用户目标
        builder
            .addCase(setUserGoal.pending, (state) => {
                state.userGoal.status = 'loading';
                state.userGoal.error = null;
            })
            .addCase(setUserGoal.fulfilled, (state, action) => {
                state.userGoal.status = 'succeeded';
                state.userGoal.data = action.payload?.data || action.payload;
                state.userGoal.error = null;
            })
            .addCase(setUserGoal.rejected, (state, action) => {
                state.userGoal.status = 'failed';
                state.userGoal.error = action.payload || action.error.message;
            })

            // 获取会话摘要
            .addCase(getConversationSummary.pending, (state) => {
                state.conversationSummary.status = 'loading';
                state.conversationSummary.error = null;
            })
            .addCase(getConversationSummary.fulfilled, (state, action) => {
                state.conversationSummary.status = 'succeeded';
                state.conversationSummary.data = action.payload || null;
                state.conversationSummary.error = null;
            })
            .addCase(getConversationSummary.rejected, (state, action) => {
                state.conversationSummary.status = 'failed';
                state.conversationSummary.error = action.payload || action.error.message;
            })

            // 获取推荐回复
            .addCase(getRecommendedReply.pending, (state) => {
                state.recommendedReply.status = 'loading';
                state.recommendedReply.error = null;
            })
            .addCase(getRecommendedReply.fulfilled, (state, action) => {
                state.recommendedReply.status = 'succeeded';
                state.recommendedReply.data = action.payload?.data || action.payload;
                state.recommendedReply.error = null;
            })
            .addCase(getRecommendedReply.rejected, (state, action) => {
                state.recommendedReply.status = 'failed';
                state.recommendedReply.error = action.payload || action.error.message;
            });
    }
});

export const { resetTalentChat } = talentChatSlice.actions;
export default talentChatSlice.reducer;
