import { createAsyncThunk } from '@reduxjs/toolkit';
import axios from 'axios';
import { post, get } from '../../services/api';

export const setUserGoal = createAsyncThunk('talentChat/setUserGoal', async (content, { rejectWithValue }) => {
    try {
        const requestData = {
            content,
        };

        const response = await post('/user-goal/', requestData);
        return response;
    } catch (error) {
        return rejectWithValue(error.response?.data?.message || error.message || 'Failed to set user goal');
    }
});

export const getConversationSummary = createAsyncThunk(
    'talentChat/getConversationSummary',
    async (talentEmail, { rejectWithValue }) => {
        try {
            const params = {
                talent_email: talentEmail,
            };

            const { summary } = await get('/conversation-summary/', { params });
            return summary;
        } catch (error) {
            return rejectWithValue(
                error.response?.data?.message || error.message || 'Failed to get conversation summary'
            );
        }
    }
);

export const getRecommendedReply = createAsyncThunk(
    'talentChat/getRecommendedReply',
    async ({ conversation_id, talent_email }, { rejectWithValue }) => {
        try {
            const requestData = {
                conversation_id,
                talent_email,
            };

            const response = await post('/recommended-reply/', requestData);
            return response;
        } catch (error) {
            return rejectWithValue(error.response?.data?.message || error.message || 'Failed to get recommended reply');
        }
    }
);
